@@ -65,3 +65,33 @@ def display_results(df, *args, w_mat=None, title='', palette=None, figsize=(16,
     ma.display_kpi()
     ma.plot_perf(logy=True, title=title, y=strats, ax=ax, color=palette, show=False)
     ma.plot_perf(logy=True, title=title, y=list(args), ax=ax, c='k', lw=2)
+
+
+def display_weight_results(df, *args, w_mat=None, title='', palette=None, figsize=(16, 16),strats=None):
+    N = df.columns.size - len(args)
+    if palette is None:
+        palette = rand_color_palette(N)
+
+    if w_mat is None:
+        f, ax = plt.subplots(1, 1, figsize=figsize)
+        print('no weights given')
+    else:
+        n = sum(w_mat.sum(axis=1) == 0.)
+        f, (ax, ax2) = plt.subplots(2, 1, figsize=figsize)
+        ax4 = f.add_subplot(2, 2, 4)
+        ax3 = f.add_subplot(2, 2, 3, sharey=ax2)
+        w_mat.iloc[n:].mean(axis=0).plot(
+            kind='pie',
+            ax=ax4,
+            title='Mean of weights allocation',
+            colors=palette
+        )
+        ax4.set_ylabel('weights in %', fontsize=12, y=0.5, x=-0.5, rotation=0)
+        ax2.set_xticks([])
+        w_mat.iloc[n:].plot(
+            ax=ax3,
+            kind='area',
+            stacked=True,
+            title='Weights allocation',
+            color=palette
+        )
